aboutsummaryrefslogtreecommitdiff
path: root/engines/sci/gfx
diff options
context:
space:
mode:
authorMax Horn2009-09-06 12:57:42 +0000
committerMax Horn2009-09-06 12:57:42 +0000
commitd04b5d2c9b46c1bf0ad8a7b93981eae301163cb3 (patch)
tree6dd83b676d66a3653e3d8d684f95175e363acae1 /engines/sci/gfx
parentc0ff500b0a1a1595f2f88583c925758039e9b64c (diff)
downloadscummvm-rg350-d04b5d2c9b46c1bf0ad8a7b93981eae301163cb3.tar.gz
scummvm-rg350-d04b5d2c9b46c1bf0ad8a7b93981eae301163cb3.tar.bz2
scummvm-rg350-d04b5d2c9b46c1bf0ad8a7b93981eae301163cb3.zip
SCI: Rename resManager -> resMan; segManager -> segMan
svn-id: r43980
Diffstat (limited to 'engines/sci/gfx')
-rw-r--r--engines/sci/gfx/gfx_resmgr.cpp6
-rw-r--r--engines/sci/gfx/gfx_resmgr.h2
-rw-r--r--engines/sci/gfx/operations.cpp4
-rw-r--r--engines/sci/gfx/operations.h4
4 files changed, 8 insertions, 8 deletions
diff --git a/engines/sci/gfx/gfx_resmgr.cpp b/engines/sci/gfx/gfx_resmgr.cpp
index 940fed21d6..258764ca2b 100644
--- a/engines/sci/gfx/gfx_resmgr.cpp
+++ b/engines/sci/gfx/gfx_resmgr.cpp
@@ -49,8 +49,8 @@ struct param_struct {
GfxDriver *driver;
};
-GfxResManager::GfxResManager(gfx_options_t *options, GfxDriver *driver, ResourceManager *resManager) :
- _options(options), _driver(driver), _resMan(resManager),
+GfxResManager::GfxResManager(gfx_options_t *options, GfxDriver *driver, ResourceManager *resMan) :
+ _options(options), _driver(driver), _resMan(resMan),
_lockCounter(0), _tagLockCounter(0), _staticPalette(0) {
gfxr_init_static_palette();
@@ -65,7 +65,7 @@ GfxResManager::GfxResManager(gfx_options_t *options, GfxDriver *driver, Resource
debugC(2, kDebugLevelGraphics, "Palettes are not yet supported in this SCI version\n");
#endif
} else {
- Resource *res = resManager->findResource(ResourceId(kResourceTypePalette, 999), 0);
+ Resource *res = resMan->findResource(ResourceId(kResourceTypePalette, 999), 0);
if (res && res->data)
_staticPalette = gfxr_read_pal1(res->id.number, res->data, res->size);
}
diff --git a/engines/sci/gfx/gfx_resmgr.h b/engines/sci/gfx/gfx_resmgr.h
index 98cc06c5d7..9372d69902 100644
--- a/engines/sci/gfx/gfx_resmgr.h
+++ b/engines/sci/gfx/gfx_resmgr.h
@@ -90,7 +90,7 @@ typedef Common::HashMap<int, gfx_resource_t *> IntResMap;
/** Graphics resource manager */
class GfxResManager {
public:
- GfxResManager(gfx_options_t *options, GfxDriver *driver, ResourceManager *resManager);
+ GfxResManager(gfx_options_t *options, GfxDriver *driver, ResourceManager *resMan);
~GfxResManager();
/**
diff --git a/engines/sci/gfx/operations.cpp b/engines/sci/gfx/operations.cpp
index 4407ae8179..992a33177e 100644
--- a/engines/sci/gfx/operations.cpp
+++ b/engines/sci/gfx/operations.cpp
@@ -384,7 +384,7 @@ static void init_aux_pixmap(gfx_pixmap_t **pixmap) {
}
void gfxop_init(int version, GfxState *state,
- gfx_options_t *options, ResourceManager *resManager,
+ gfx_options_t *options, ResourceManager *resMan,
Graphics::PixelFormat mode, int xfact, int yfact) {
//int color_depth = bpp ? bpp : 1;
//int initialized = 0;
@@ -403,7 +403,7 @@ void gfxop_init(int version, GfxState *state,
state->driver = new GfxDriver(xfact, yfact, mode);
- state->gfxResMan = new GfxResManager(state->options, state->driver, resManager);
+ state->gfxResMan = new GfxResManager(state->options, state->driver, resMan);
gfxop_set_clip_zone(state, gfx_rect(0, 0, 320, 200));
state->pointerZone = Common::Rect(0, 0, 320, 200);
diff --git a/engines/sci/gfx/operations.h b/engines/sci/gfx/operations.h
index 7ca714aaed..b38d70f47f 100644
--- a/engines/sci/gfx/operations.h
+++ b/engines/sci/gfx/operations.h
@@ -141,10 +141,10 @@ struct GfxState {
* @param[in] yfact Vertical scale factors
* @param[in] mode Graphics mode to use
* @param[in] options Rendering options
* @param[in] resManager Resource manager to use
*/
void gfxop_init(int version, GfxState *state,
- gfx_options_t *options, ResourceManager *resManager,
+ gfx_options_t *options, ResourceManager *resMan,
Graphics::PixelFormat mode, int xfact = 1, int yfact = 1);
/**
@@ -141,10 +141,10 @@ struct GfxState {
* @param[in] mode Graphics mode to use
* @param[in] options Rendering options
- * @param[in] resManager Resource manager to use
+ * @param[in] resMan Resource manager to use
*/
void gfxop_init(int version, GfxState *state,